@@ -46,7 +46,9 @@ ChannelsForm::ChannelsForm(QWidget *parent) :
     connect(&http, SIGNAL(requestFinished(int,bool)),
              this, SLOT(finished(int,bool)));
 
-    connect(ui->channelsWidget, SIGNAL(currentRowChanged(int)), this, SLOT(updateChannelInfo(int)));
+    //connect(ui->channelsWidget, SIGNAL(currentRowChanged(int)), this, SLOT(updateChannelInfo(int)));
+    connect(ui->channelsWidget, SIGNAL(itemActivated(QListWidgetItem*)), this, SLOT(updateChannelInfo(QListWidgetItem*)));
+    connect(ui->channelsWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(updateChannelInfo(QListWidgetItem*)));
 
     connect(ui->abortButton, SIGNAL(clicked()), this, SLOT(abortFetching()));
 
@@ -241,6 +243,11 @@ bool channelInfoAlreadyShown(const QString &value)
     return (value == "image" || value == "title");
 }
 
+void ChannelsForm::updateChannelInfo(QListWidgetItem *item)
+{
+    updateChannelInfo(item->listWidget()->row(item));
+}
+
 void ChannelsForm::updateChannelInfo(int position)
 {
     if (position < 0)
